@@ -5,10 +5,12 @@
   # Register on package load because vctrs depends on glue and will
   # not be fully loaded when glue is loaded
   on_package_load("vctrs", {
-    register_s3_method("vctrs", "vec_ptype2", "glue")
-    register_s3_method("vctrs", "vec_ptype2.character", "glue")
-    register_s3_method("vctrs", "vec_cast", "glue")
-    register_s3_method("vctrs", "vec_cast.character", "glue")
+    register_s3_method("vctrs", "vec_ptype2", "glue.glue")
+    register_s3_method("vctrs", "vec_ptype2", "character.glue")
+    register_s3_method("vctrs", "vec_ptype2", "glue.character")
+    register_s3_method("vctrs", "vec_cast", "glue.glue")
+    register_s3_method("vctrs", "vec_cast", "character.glue")
+    register_s3_method("vctrs", "vec_cast", "glue.character")
   })
 
   invisible()
